@@ -203,7 +203,7 @@ class TestManagedColls(CollsDirMixin, BaseConfigTest):
 
         resp = self.testapp.get('/static/_/test/abc.js')
         assert resp.status_int == 200
-        assert resp.content_type == 'application/javascript'
+        assert resp.content_type in ('application/javascript', 'text/javascript')
         resp.charset = 'utf-8'
         assert '/* Some JS File */' in resp.text
 
@@ -275,18 +275,19 @@ class TestManagedColls(CollsDirMixin, BaseConfigTest):
         assert 'pywb custom search page' in resp.text
 
     def test_add_custom_banner(self):
-        """ Test adding custom banner.html per-collection template
+        """ Test adding custom_banner.html per-collection template
         """
 
         banner_file = os.path.join(self.root_dir, COLLECTIONS, 'test',
-                                   'templates', 'banner.html')
+                                   'templates', 'custom_banner.html')
 
         with open(banner_file, 'w+b') as fh:
             fh.write(b'<div>Custom Banner Here!</div>')
             fh.write(b'\n{{ metadata | tojson }}')
 
-    def test_add_custom_banner_replay(self, fmod):
-        resp = self.get('/test/20140103030321/http://example.com/?example=1', fmod)
+    def test_add_custom_banner_replay(self):
+        """Test custom banner appears in unframed replay."""
+        resp = self.get('/test/20140103030321/http://example.com/?example=1', None)
         assert '<div>Custom Banner Here!</div>' in resp.text
 
     def test_more_custom_templates(self):
@@ -316,10 +317,9 @@ class TestManagedColls(CollsDirMixin, BaseConfigTest):
         #assert '"some":"value"' in resp.text, resp.text
         assert '{&#34;some&#34;:&#34;value&#34;}' in resp.text, resp.text
 
-    def test_replay_banner_metadata(self, fmod):
-        """ Test adding metadata in replay banner (both framed and non-frame)
-        """
-        resp = self.get('/test/20140103030321{0}/http://example.com/?example=1', fmod)
+    def test_replay_banner_metadata(self):
+        """Test adding metadata in custom banner for unframed replay."""
+        resp = self.get('/test/20140103030321/http://example.com/?example=1', None)
         assert '<div>Custom Banner Here!</div>' in resp.text
         #assert '"some":"value"' in resp.text
         assert '{&#34;some&#34;:&#34;value&#34;}' in resp.text, resp.text
